@@ -48,11 +48,11 @@ use constant	DEFAULT_MAX_SLURP_SIZE => 16 * 1024;	# CSV files <= than this size
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 =head1 SYNOPSIS
 
@@ -591,7 +591,10 @@ sub selectall_hash
 	if($self->{'data'}) {
 		if(scalar(keys %{$params}) == 0) {
 			$self->_trace("$table: selectall_hash fast track return");
-			return values %{$self->{'data'}};
+			if(ref($self->{'data'}) eq 'HASH') {
+				return values %{$self->{'data'}};
+			}
+			return @{$self->{'data'}};
 			# my @rc = values %{$self->{'data'}};
 			# return @rc;
 		} elsif((scalar(keys %{$params}) == 1) && defined($params->{'entry'}) && !$self->{'no_entry'}) {
